@@ -11,11 +11,11 @@ WebService::Linode::DNS - Perl Interface to the Linode.com API DNS methods.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 our @ISA = ("WebService::Linode");
 
 sub getDomainIDbyName {
@@ -261,7 +261,7 @@ Example usage:
 	use WebService::Linode::DNS;
 
 	my $api = new WebService::Linode::DNS(apikey => 'mmmcake');
-	for my $domain (@{$api->listDomains}) {
+	for my $domain (@{$api->domainList}) {
 		print $domain->{domainid}, "\n";
 	}
 
